![logo](https://github.com/anytarseir67/RedditUserDownloader/blob/main/docs/source/images/logo.png?raw=True)
# RedditUserDownloader
 python cli and library to selectively download a reddit users posts

 ## documentation can be found at https://reddituserdownloader.readthedocs.io/